@@ -3,8 +3,6 @@ import json
 import requests
 
 
-
-
 def anonymize_request(body: dict) -> dict:
     res = body.copy()
     res.update(User='***', Pwd='***')
@@ -53,11 +51,11 @@ class EmptyDataException(CityAirException):
     """
 
     def __init__(self, response: requests.models.Response = None, item=None):
-        message = (f"No data for the request. Try changing query arguments, "
-                   f"i.e. start_date or finish_date.")
+        message = ("No data for the request. Try changing query arguments, "
+                   "i.e. start_date or finish_date.")
         if response:
             body = anonymize_request(
-                json.loads(response.request.body.decode('utf-8')))
+                    json.loads(response.request.body.decode('utf-8')))
             message += f"\nurl: {response.url}\nrequest body: {body}\n"
         if item:
             message = message.replace("request", f"{item}")
